﻿using System;
using System.IO;
using System.Reflection;
using System.Text;
using System.Windows.Forms;
using System.Xml;

namespace XmlResource
{
    static class Program
    {
        /// <summary>
        /// アプリケーションのメイン エントリ ポイントです。
        /// </summary>
        [STAThread]
        static void Main( string[] args )
        {
            if( args.Length > 0 && File.Exists( args[0] ) ) {
                // ファイルの読み込み
                byte[] data = File.ReadAllBytes( args[0] );

                // Base64で文字列に変換
                string base64 = Convert.ToBase64String( data );

                // 確認しやすいように90文字ごとに分割
                int len = 90;
                int count = (base64.Length / len) + ((base64.Length % len) > 0 ? 1 : 0);
                StringBuilder text = new StringBuilder();
                text.AppendLine(); // 位置を揃えるために改行を入れておく
                for( int i = 0; i < count; i++ ) {
                    // 文字列の分割
                    text.AppendLine( base64.Substring( len * i, ((len * i) + len <= base64.Length) ? len : (base64.Length - (len * i)) ) );
                }

                // xmlファイルを作成する
                XmlDocument xml = new XmlDocument();
                xml.AppendChild( xml.CreateXmlDeclaration( "1.0", "utf-8", "yes" ) );

                // ルートノードの作成
                XmlNode root = xml.CreateNode( XmlNodeType.Element, "Sample", xml.NamespaceURI );
                xml.AppendChild( root );

                // リソース格納用のノードを作成
                XmlNode resource = xml.CreateNode( XmlNodeType.Element, "Resource", xml.NamespaceURI );
                resource.InnerText = text.ToString();
                root.AppendChild( resource );

                // xmlファイルを保存
                string folder = Path.GetDirectoryName( Assembly.GetExecutingAssembly().Location );
                xml.Save( Path.Combine( folder, "sample.xml" ) );
            }
            else {
                Application.EnableVisualStyles();
                Application.SetCompatibleTextRenderingDefault( false );
                Application.Run( new Form1() );
            }
        }
    }
}
